# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/format_schema.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/clickhouse/v1/format_schema.proto',
  package='yandex.cloud.mdb.clickhouse.v1',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2yandex/cloud/mdb/clickhouse/v1/format_schema.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\"}\n\x0c\x46ormatSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12>\n\x04type\x18\x03 \x01(\x0e\x32\x30.yandex.cloud.mdb.clickhouse.v1.FormatSchemaType\x12\x0b\n\x03uri\x18\x04 \x01(\t*y\n\x10\x46ormatSchemaType\x12\"\n\x1e\x46ORMAT_SCHEMA_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x46ORMAT_SCHEMA_TYPE_PROTOBUF\x10\x01\x12 \n\x1c\x46ORMAT_SCHEMA_TYPE_CAPNPROTO\x10\x02\x42s\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3'
)

_FORMATSCHEMATYPE = _descriptor.EnumDescriptor(
  name='FormatSchemaType',
  full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchemaType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FORMAT_SCHEMA_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORMAT_SCHEMA_TYPE_PROTOBUF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORMAT_SCHEMA_TYPE_CAPNPROTO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=213,
  serialized_end=334,
)
_sym_db.RegisterEnumDescriptor(_FORMATSCHEMATYPE)

FormatSchemaType = enum_type_wrapper.EnumTypeWrapper(_FORMATSCHEMATYPE)
FORMAT_SCHEMA_TYPE_UNSPECIFIED = 0
FORMAT_SCHEMA_TYPE_PROTOBUF = 1
FORMAT_SCHEMA_TYPE_CAPNPROTO = 2



_FORMATSCHEMA = _descriptor.Descriptor(
  name='FormatSchema',
  full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchema.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchema.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchema.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchema.uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=211,
)

_FORMATSCHEMA.fields_by_name['type'].enum_type = _FORMATSCHEMATYPE
DESCRIPTOR.message_types_by_name['FormatSchema'] = _FORMATSCHEMA
DESCRIPTOR.enum_types_by_name['FormatSchemaType'] = _FORMATSCHEMATYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FormatSchema = _reflection.GeneratedProtocolMessageType('FormatSchema', (_message.Message,), {
  'DESCRIPTOR' : _FORMATSCHEMA,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.format_schema_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.FormatSchema)
  })
_sym_db.RegisterMessage(FormatSchema)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2
from yandex.cloud.cdn.v1 import origin_service_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class OriginServiceStub(object):
    """
    Origin management service.
    Origin is not a standalone entity. It can live only within origin group.

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.cdn.v1.OriginService/Get',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.GetOriginRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2.Origin.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.cdn.v1.OriginService/List',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.ListOriginsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.ListOriginsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.cdn.v1.OriginService/Create',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.CreateOriginRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.cdn.v1.OriginService/Update',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.UpdateOriginRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.cdn.v1.OriginService/Delete',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.DeleteOriginRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class OriginServiceServicer(object):
    """
    Origin management service.
    Origin is not a standalone entity. It can live only within origin group.

    """

    def Get(self, request, context):
        """Get origin in origin group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists origins of origin group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates origin inside origin group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified origin from the origin group.

        Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge cache of the resources that
        use the origin via a [CacheService.Purge] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes origin from origin group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OriginServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.GetOriginRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2.Origin.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.ListOriginsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.ListOriginsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.CreateOriginRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.UpdateOriginRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.DeleteOriginRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.cdn.v1.OriginService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OriginService(object):
    """
    Origin management service.
    Origin is not a standalone entity. It can live only within origin group.

    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.OriginService/Get',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.GetOriginRequest.SerializeToString,
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2.Origin.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.OriginService/List',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.ListOriginsRequest.SerializeToString,
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.ListOriginsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.OriginService/Create',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.CreateOriginRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.OriginService/Update',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.UpdateOriginRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.OriginService/Delete',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__service__pb2.DeleteOriginRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/unit_format.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/unit_format.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,yandex/cloud/monitoring/v3/unit_format.proto\x12\x1ayandex.cloud.monitoring.v3*\xa0\x11\n\nUnitFormat\x12\x1b\n\x17UNIT_FORMAT_UNSPECIFIED\x10\x00\x12\r\n\tUNIT_NONE\x10\x01\x12\x0e\n\nUNIT_COUNT\x10\x02\x12\x10\n\x0cUNIT_PERCENT\x10\x03\x12\x15\n\x11UNIT_PERCENT_UNIT\x10\x04\x12\x14\n\x10UNIT_NANOSECONDS\x10\x05\x12\x15\n\x11UNIT_MICROSECONDS\x10\x06\x12\x15\n\x11UNIT_MILLISECONDS\x10\x07\x12\x10\n\x0cUNIT_SECONDS\x10\x08\x12\x10\n\x0cUNIT_MINUTES\x10\t\x12\x0e\n\nUNIT_HOURS\x10\n\x12\r\n\tUNIT_DAYS\x10\x0b\x12\x10\n\x0cUNIT_BITS_SI\x10\x0c\x12\x11\n\rUNIT_BYTES_SI\x10\r\x12\x12\n\x0eUNIT_KILOBYTES\x10\x0e\x12\x12\n\x0eUNIT_MEGABYTES\x10\x0f\x12\x12\n\x0eUNIT_GIGABYTES\x10\x10\x12\x12\n\x0eUNIT_TERABYTES\x10\x11\x12\x12\n\x0eUNIT_PETABYTES\x10\x12\x12\x11\n\rUNIT_EXABYTES\x10\x13\x12\x11\n\rUNIT_BITS_IEC\x10\x14\x12\x12\n\x0eUNIT_BYTES_IEC\x10\x15\x12\x12\n\x0eUNIT_KIBIBYTES\x10\x16\x12\x12\n\x0eUNIT_MEBIBYTES\x10\x17\x12\x12\n\x0eUNIT_GIBIBYTES\x10\x18\x12\x12\n\x0eUNIT_TEBIBYTES\x10\x19\x12\x12\n\x0eUNIT_PEBIBYTES\x10\x1a\x12\x12\n\x0eUNIT_EXBIBYTES\x10\x1b\x12\x1c\n\x18UNIT_REQUESTS_PER_SECOND\x10\x1c\x12\x1e\n\x1aUNIT_OPERATIONS_PER_SECOND\x10\x1d\x12\x1a\n\x16UNIT_WRITES_PER_SECOND\x10\x1e\x12\x19\n\x15UNIT_READS_PER_SECOND\x10\x1f\x12\x1b\n\x17UNIT_PACKETS_PER_SECOND\x10 \x12!\n\x1dUNIT_IO_OPERATIONS_PER_SECOND\x10!\x12\x1a\n\x16UNIT_COUNTS_PER_SECOND\x10\"\x12\x1b\n\x17UNIT_BITS_SI_PER_SECOND\x10#\x12\x1c\n\x18UNIT_BYTES_SI_PER_SECOND\x10$\x12\x1c\n\x18UNIT_KILOBITS_PER_SECOND\x10%\x12\x1d\n\x19UNIT_KILOBYTES_PER_SECOND\x10&\x12\x1c\n\x18UNIT_MEGABITS_PER_SECOND\x10\'\x12\x1d\n\x19UNIT_MEGABYTES_PER_SECOND\x10(\x12\x1c\n\x18UNIT_GIGABITS_PER_SECOND\x10)\x12\x1d\n\x19UNIT_GIGABYTES_PER_SECOND\x10*\x12\x1c\n\x18UNIT_TERABITS_PER_SECOND\x10+\x12\x1d\n\x19UNIT_TERABYTES_PER_SECOND\x10,\x12\x1c\n\x18UNIT_PETABITS_PER_SECOND\x10-\x12\x1d\n\x19UNIT_PETABYTES_PER_SECOND\x10.\x12\x1c\n\x18UNIT_BITS_IEC_PER_SECOND\x10/\x12\x1d\n\x19UNIT_BYTES_IEC_PER_SECOND\x10\x30\x12\x1c\n\x18UNIT_KIBIBITS_PER_SECOND\x10\x31\x12\x1d\n\x19UNIT_KIBIBYTES_PER_SECOND\x10\x32\x12\x1c\n\x18UNIT_MEBIBITS_PER_SECOND\x10\x33\x12\x1d\n\x19UNIT_MEBIBYTES_PER_SECOND\x10\x34\x12\x1c\n\x18UNIT_GIBIBITS_PER_SECOND\x10\x35\x12\x1d\n\x19UNIT_GIBIBYTES_PER_SECOND\x10\x36\x12\x1c\n\x18UNIT_TEBIBITS_PER_SECOND\x10\x37\x12\x1d\n\x19UNIT_TEBIBYTES_PER_SECOND\x10\x38\x12\x1c\n\x18UNIT_PEBIBITS_PER_SECOND\x10\x39\x12\x1d\n\x19UNIT_PEBIBYTES_PER_SECOND\x10:\x12\x15\n\x11UNIT_DATETIME_UTC\x10;\x12\x17\n\x13UNIT_DATETIME_LOCAL\x10<\x12\x0e\n\nUNIT_HERTZ\x10=\x12\x12\n\x0eUNIT_KILOHERTZ\x10>\x12\x12\n\x0eUNIT_MEGAHERTZ\x10?\x12\x12\n\x0eUNIT_GIGAHERTZ\x10@\x12\x0f\n\x0bUNIT_DOLLAR\x10\x41\x12\r\n\tUNIT_EURO\x10\x42\x12\x0f\n\x0bUNIT_ROUBLE\x10\x43\x12\x10\n\x0cUNIT_CELSIUS\x10\x44\x12\x13\n\x0fUNIT_FAHRENHEIT\x10\x45\x12\x0f\n\x0bUNIT_KELVIN\x10\x46\x12\x18\n\x14UNIT_FLOP_PER_SECOND\x10G\x12\x1c\n\x18UNIT_KILOFLOP_PER_SECOND\x10H\x12\x1c\n\x18UNIT_MEGAFLOP_PER_SECOND\x10I\x12\x1c\n\x18UNIT_GIGAFLOP_PER_SECOND\x10J\x12\x1c\n\x18UNIT_PETAFLOP_PER_SECOND\x10K\x12\x1b\n\x17UNIT_EXAFLOP_PER_SECOND\x10L\x12\x1a\n\x16UNIT_METERS_PER_SECOND\x10M\x12\x1c\n\x18UNIT_KILOMETERS_PER_HOUR\x10N\x12\x17\n\x13UNIT_MILES_PER_HOUR\x10O\x12\x13\n\x0fUNIT_MILLIMETER\x10P\x12\x13\n\x0fUNIT_CENTIMETER\x10Q\x12\x0e\n\nUNIT_METER\x10R\x12\x12\n\x0eUNIT_KILOMETER\x10S\x12\r\n\tUNIT_MILE\x10T\x12\x0c\n\x08UNIT_PPM\x10U\x12\x1a\n\x16UNIT_EVENTS_PER_SECOND\x10V\x12\x10\n\x0cUNIT_PACKETS\x10W\x12\x0c\n\x08UNIT_DBM\x10X\x12\x14\n\x10UNIT_VIRTUAL_CPU\x10Y\x12\x1c\n\x18UNIT_MESSAGES_PER_SECOND\x10ZBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
)

_UNITFORMAT = _descriptor.EnumDescriptor(
  name='UnitFormat',
  full_name='yandex.cloud.monitoring.v3.UnitFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNIT_FORMAT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_COUNT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PERCENT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PERCENT_UNIT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_NANOSECONDS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MICROSECONDS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MILLISECONDS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_SECONDS', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MINUTES', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_HOURS', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_DAYS', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BITS_SI', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BYTES_SI', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOBYTES', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEGABYTES', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIGABYTES', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TERABYTES', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PETABYTES', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_EXABYTES', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BITS_IEC', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BYTES_IEC', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KIBIBYTES', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEBIBYTES', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIBIBYTES', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TEBIBYTES', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PEBIBYTES', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_EXBIBYTES', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_REQUESTS_PER_SECOND', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_OPERATIONS_PER_SECOND', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_WRITES_PER_SECOND', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_READS_PER_SECOND', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PACKETS_PER_SECOND', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_IO_OPERATIONS_PER_SECOND', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_COUNTS_PER_SECOND', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BITS_SI_PER_SECOND', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BYTES_SI_PER_SECOND', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOBITS_PER_SECOND', index=37, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOBYTES_PER_SECOND', index=38, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEGABITS_PER_SECOND', index=39, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEGABYTES_PER_SECOND', index=40, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIGABITS_PER_SECOND', index=41, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIGABYTES_PER_SECOND', index=42, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TERABITS_PER_SECOND', index=43, number=43,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TERABYTES_PER_SECOND', index=44, number=44,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PETABITS_PER_SECOND', index=45, number=45,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PETABYTES_PER_SECOND', index=46, number=46,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BITS_IEC_PER_SECOND', index=47, number=47,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BYTES_IEC_PER_SECOND', index=48, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KIBIBITS_PER_SECOND', index=49, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KIBIBYTES_PER_SECOND', index=50, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEBIBITS_PER_SECOND', index=51, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEBIBYTES_PER_SECOND', index=52, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIBIBITS_PER_SECOND', index=53, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIBIBYTES_PER_SECOND', index=54, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TEBIBITS_PER_SECOND', index=55, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TEBIBYTES_PER_SECOND', index=56, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PEBIBITS_PER_SECOND', index=57, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PEBIBYTES_PER_SECOND', index=58, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_DATETIME_UTC', index=59, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_DATETIME_LOCAL', index=60, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_HERTZ', index=61, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOHERTZ', index=62, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEGAHERTZ', index=63, number=63,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIGAHERTZ', index=64, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_DOLLAR', index=65, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_EURO', index=66, number=66,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_ROUBLE', index=67, number=67,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_CELSIUS', index=68, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_FAHRENHEIT', index=69, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KELVIN', index=70, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_FLOP_PER_SECOND', index=71, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOFLOP_PER_SECOND', index=72, number=72,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEGAFLOP_PER_SECOND', index=73, number=73,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIGAFLOP_PER_SECOND', index=74, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PETAFLOP_PER_SECOND', index=75, number=75,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_EXAFLOP_PER_SECOND', index=76, number=76,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_METERS_PER_SECOND', index=77, number=77,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOMETERS_PER_HOUR', index=78, number=78,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MILES_PER_HOUR', index=79, number=79,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MILLIMETER', index=80, number=80,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_CENTIMETER', index=81, number=81,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_METER', index=82, number=82,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOMETER', index=83, number=83,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MILE', index=84, number=84,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PPM', index=85, number=85,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_EVENTS_PER_SECOND', index=86, number=86,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PACKETS', index=87, number=87,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_DBM', index=88, number=88,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_VIRTUAL_CPU', index=89, number=89,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MESSAGES_PER_SECOND', index=90, number=90,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=77,
  serialized_end=2285,
)
_sym_db.RegisterEnumDescriptor(_UNITFORMAT)

UnitFormat = enum_type_wrapper.EnumTypeWrapper(_UNITFORMAT)
UNIT_FORMAT_UNSPECIFIED = 0
UNIT_NONE = 1
UNIT_COUNT = 2
UNIT_PERCENT = 3
UNIT_PERCENT_UNIT = 4
UNIT_NANOSECONDS = 5
UNIT_MICROSECONDS = 6
UNIT_MILLISECONDS = 7
UNIT_SECONDS = 8
UNIT_MINUTES = 9
UNIT_HOURS = 10
UNIT_DAYS = 11
UNIT_BITS_SI = 12
UNIT_BYTES_SI = 13
UNIT_KILOBYTES = 14
UNIT_MEGABYTES = 15
UNIT_GIGABYTES = 16
UNIT_TERABYTES = 17
UNIT_PETABYTES = 18
UNIT_EXABYTES = 19
UNIT_BITS_IEC = 20
UNIT_BYTES_IEC = 21
UNIT_KIBIBYTES = 22
UNIT_MEBIBYTES = 23
UNIT_GIBIBYTES = 24
UNIT_TEBIBYTES = 25
UNIT_PEBIBYTES = 26
UNIT_EXBIBYTES = 27
UNIT_REQUESTS_PER_SECOND = 28
UNIT_OPERATIONS_PER_SECOND = 29
UNIT_WRITES_PER_SECOND = 30
UNIT_READS_PER_SECOND = 31
UNIT_PACKETS_PER_SECOND = 32
UNIT_IO_OPERATIONS_PER_SECOND = 33
UNIT_COUNTS_PER_SECOND = 34
UNIT_BITS_SI_PER_SECOND = 35
UNIT_BYTES_SI_PER_SECOND = 36
UNIT_KILOBITS_PER_SECOND = 37
UNIT_KILOBYTES_PER_SECOND = 38
UNIT_MEGABITS_PER_SECOND = 39
UNIT_MEGABYTES_PER_SECOND = 40
UNIT_GIGABITS_PER_SECOND = 41
UNIT_GIGABYTES_PER_SECOND = 42
UNIT_TERABITS_PER_SECOND = 43
UNIT_TERABYTES_PER_SECOND = 44
UNIT_PETABITS_PER_SECOND = 45
UNIT_PETABYTES_PER_SECOND = 46
UNIT_BITS_IEC_PER_SECOND = 47
UNIT_BYTES_IEC_PER_SECOND = 48
UNIT_KIBIBITS_PER_SECOND = 49
UNIT_KIBIBYTES_PER_SECOND = 50
UNIT_MEBIBITS_PER_SECOND = 51
UNIT_MEBIBYTES_PER_SECOND = 52
UNIT_GIBIBITS_PER_SECOND = 53
UNIT_GIBIBYTES_PER_SECOND = 54
UNIT_TEBIBITS_PER_SECOND = 55
UNIT_TEBIBYTES_PER_SECOND = 56
UNIT_PEBIBITS_PER_SECOND = 57
UNIT_PEBIBYTES_PER_SECOND = 58
UNIT_DATETIME_UTC = 59
UNIT_DATETIME_LOCAL = 60
UNIT_HERTZ = 61
UNIT_KILOHERTZ = 62
UNIT_MEGAHERTZ = 63
UNIT_GIGAHERTZ = 64
UNIT_DOLLAR = 65
UNIT_EURO = 66
UNIT_ROUBLE = 67
UNIT_CELSIUS = 68
UNIT_FAHRENHEIT = 69
UNIT_KELVIN = 70
UNIT_FLOP_PER_SECOND = 71
UNIT_KILOFLOP_PER_SECOND = 72
UNIT_MEGAFLOP_PER_SECOND = 73
UNIT_GIGAFLOP_PER_SECOND = 74
UNIT_PETAFLOP_PER_SECOND = 75
UNIT_EXAFLOP_PER_SECOND = 76
UNIT_METERS_PER_SECOND = 77
UNIT_KILOMETERS_PER_HOUR = 78
UNIT_MILES_PER_HOUR = 79
UNIT_MILLIMETER = 80
UNIT_CENTIMETER = 81
UNIT_METER = 82
UNIT_KILOMETER = 83
UNIT_MILE = 84
UNIT_PPM = 85
UNIT_EVENTS_PER_SECOND = 86
UNIT_PACKETS = 87
UNIT_DBM = 88
UNIT_VIRTUAL_CPU = 89
UNIT_MESSAGES_PER_SECOND = 90


DESCRIPTOR.enum_types_by_name['UnitFormat'] = _UNITFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/sink_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.logging.v1 import sink_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/logging/v1/sink_service.proto',
  package='yandex.cloud.logging.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/logging/v1/sink_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\"yandex/cloud/logging/v1/sink.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x0eGetSinkRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"\x81\x01\n\x10ListSinksRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x11\n\tpage_size\x18\x03 \x01(\x03\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"Z\n\x11ListSinksResponse\x12,\n\x05sinks\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.logging.v1.Sink\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xec\x03\n\x11\x43reateSinkRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x87\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x36.yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12<\n\x12service_account_id\x18\x05 \x01(\tB \xf2\xc7\x31\x1c[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x30\n\x03yds\x18\x06 \x01(\x0b\x32!.yandex.cloud.logging.v1.Sink.YdsH\x00\x12.\n\x02s3\x18\x07 \x01(\x0b\x32 .yandex.cloud.logging.v1.Sink.S3H\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04sink\x12\x04\xc0\xc1\x31\x01\"%\n\x12\x43reateSinkMetadata\x12\x0f\n\x07sink_id\x18\x01 \x01(\t\"\x9b\x04\n\x11UpdateSinkRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x87\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x36.yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12<\n\x12service_account_id\x18\x06 \x01(\tB \xf2\xc7\x31\x1c[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x30\n\x03yds\x18\x07 \x01(\x0b\x32!.yandex.cloud.logging.v1.Sink.YdsH\x00\x12.\n\x02s3\x18\x08 \x01(\x0b\x32 .yandex.cloud.logging.v1.Sink.S3H\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04sink\x12\x04\xc0\xc1\x31\x01\"%\n\x12UpdateSinkMetadata\x12\x0f\n\x07sink_id\x18\x01 \x01(\t\"2\n\x11\x44\x65leteSinkRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"%\n\x12\x44\x65leteSinkMetadata\x12\x0f\n\x07sink_id\x18\x01 \x01(\t\"\x94\x01\n\x19ListSinkOperationsRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"l\n\x1aListSinkOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x91\x0c\n\x0bSinkService\x12r\n\x03Get\x12\'.yandex.cloud.logging.v1.GetSinkRequest\x1a\x1d.yandex.cloud.logging.v1.Sink\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/logging/v1/sinks/{sink_id}\x12x\n\x04List\x12).yandex.cloud.logging.v1.ListSinksRequest\x1a*.yandex.cloud.logging.v1.ListSinksResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/logging/v1/sinks\x12\x93\x01\n\x06\x43reate\x12*.yandex.cloud.logging.v1.CreateSinkRequest\x1a!.yandex.cloud.operation.Operation\":\x82\xd3\xe4\x93\x02\x16\"\x11/logging/v1/sinks:\x01*\xb2\xd2*\x1a\n\x12\x43reateSinkMetadata\x12\x04Sink\x12\x9d\x01\n\x06Update\x12*.yandex.cloud.logging.v1.UpdateSinkRequest\x1a!.yandex.cloud.operation.Operation\"D\x82\xd3\xe4\x93\x02 2\x1b/logging/v1/sinks/{sink_id}:\x01*\xb2\xd2*\x1a\n\x12UpdateSinkMetadata\x12\x04Sink\x12\xab\x01\n\x06\x44\x65lete\x12*.yandex.cloud.logging.v1.DeleteSinkRequest\x1a!.yandex.cloud.operation.Operation\"R\x82\xd3\xe4\x93\x02\x1d*\x1b/logging/v1/sinks/{sink_id}\xb2\xd2*+\n\x12\x44\x65leteSinkMetadata\x12\x15google.protobuf.Empty\x12\xa9\x01\n\x0eListOperations\x12\x32.yandex.cloud.logging.v1.ListSinkOperationsRequest\x1a\x33.yandex.cloud.logging.v1.ListSinkOperationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/logging/v1/sinks/{sink_id}/operations\x12\xb1\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/logging/v1/sinks/{resource_id}:listAccessBindings\x12\xe0\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"y\x82\xd3\xe4\x93\x02\x36\"1/logging/v1/sinks/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xec\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\x82\xd3\xe4\x93\x02\x39\x32\x34/logging/v1/sinks/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETSINKREQUEST = _descriptor.Descriptor(
  name='GetSinkRequest',
  full_name='yandex.cloud.logging.v1.GetSinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.GetSinkRequest.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=357,
)


_LISTSINKSREQUEST = _descriptor.Descriptor(
  name='ListSinksRequest',
  full_name='yandex.cloud.logging.v1.ListSinksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.logging.v1.ListSinksRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.logging.v1.ListSinksRequest.page_size', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.logging.v1.ListSinksRequest.page_token', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.logging.v1.ListSinksRequest.filter', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=489,
)


_LISTSINKSRESPONSE = _descriptor.Descriptor(
  name='ListSinksResponse',
  full_name='yandex.cloud.logging.v1.ListSinksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sinks', full_name='yandex.cloud.logging.v1.ListSinksResponse.sinks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.logging.v1.ListSinksResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=581,
)


_CREATESINKREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1062,
)

_CREATESINKREQUEST = _descriptor.Descriptor(
  name='CreateSinkRequest',
  full_name='yandex.cloud.logging.v1.CreateSinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.logging.v1.CreateSinkRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.logging.v1.CreateSinkRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.logging.v1.CreateSinkRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.logging.v1.CreateSinkRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.logging.v1.CreateSinkRequest.service_account_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\034[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yds', full_name='yandex.cloud.logging.v1.CreateSinkRequest.yds', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3', full_name='yandex.cloud.logging.v1.CreateSinkRequest.s3', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATESINKREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sink', full_name='yandex.cloud.logging.v1.CreateSinkRequest.sink',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=584,
  serialized_end=1076,
)


_CREATESINKMETADATA = _descriptor.Descriptor(
  name='CreateSinkMetadata',
  full_name='yandex.cloud.logging.v1.CreateSinkMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.CreateSinkMetadata.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1115,
)


_UPDATESINKREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1062,
)

_UPDATESINKREQUEST = _descriptor.Descriptor(
  name='UpdateSinkRequest',
  full_name='yandex.cloud.logging.v1.UpdateSinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.service_account_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\034[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yds', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.yds', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.s3', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATESINKREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sink', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.sink',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=1118,
  serialized_end=1657,
)


_UPDATESINKMETADATA = _descriptor.Descriptor(
  name='UpdateSinkMetadata',
  full_name='yandex.cloud.logging.v1.UpdateSinkMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.UpdateSinkMetadata.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=1696,
)


_DELETESINKREQUEST = _descriptor.Descriptor(
  name='DeleteSinkRequest',
  full_name='yandex.cloud.logging.v1.DeleteSinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.DeleteSinkRequest.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1698,
  serialized_end=1748,
)


_DELETESINKMETADATA = _descriptor.Descriptor(
  name='DeleteSinkMetadata',
  full_name='yandex.cloud.logging.v1.DeleteSinkMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.DeleteSinkMetadata.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1787,
)


_LISTSINKOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListSinkOperationsRequest',
  full_name='yandex.cloud.logging.v1.ListSinkOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.ListSinkOperationsRequest.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.logging.v1.ListSinkOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.logging.v1.ListSinkOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.logging.v1.ListSinkOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1790,
  serialized_end=1938,
)


_LISTSINKOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListSinkOperationsResponse',
  full_name='yandex.cloud.logging.v1.ListSinkOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.logging.v1.ListSinkOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.logging.v1.ListSinkOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1940,
  serialized_end=2048,
)

_LISTSINKSRESPONSE.fields_by_name['sinks'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK
_CREATESINKREQUEST_LABELSENTRY.containing_type = _CREATESINKREQUEST
_CREATESINKREQUEST.fields_by_name['labels'].message_type = _CREATESINKREQUEST_LABELSENTRY
_CREATESINKREQUEST.fields_by_name['yds'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK_YDS
_CREATESINKREQUEST.fields_by_name['s3'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK_S3
_CREATESINKREQUEST.oneofs_by_name['sink'].fields.append(
  _CREATESINKREQUEST.fields_by_name['yds'])
_CREATESINKREQUEST.fields_by_name['yds'].containing_oneof = _CREATESINKREQUEST.oneofs_by_name['sink']
_CREATESINKREQUEST.oneofs_by_name['sink'].fields.append(
  _CREATESINKREQUEST.fields_by_name['s3'])
_CREATESINKREQUEST.fields_by_name['s3'].containing_oneof = _CREATESINKREQUEST.oneofs_by_name['sink']
_UPDATESINKREQUEST_LABELSENTRY.containing_type = _UPDATESINKREQUEST
_UPDATESINKREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATESINKREQUEST.fields_by_name['labels'].message_type = _UPDATESINKREQUEST_LABELSENTRY
_UPDATESINKREQUEST.fields_by_name['yds'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK_YDS
_UPDATESINKREQUEST.fields_by_name['s3'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK_S3
_UPDATESINKREQUEST.oneofs_by_name['sink'].fields.append(
  _UPDATESINKREQUEST.fields_by_name['yds'])
_UPDATESINKREQUEST.fields_by_name['yds'].containing_oneof = _UPDATESINKREQUEST.oneofs_by_name['sink']
_UPDATESINKREQUEST.oneofs_by_name['sink'].fields.append(
  _UPDATESINKREQUEST.fields_by_name['s3'])
_UPDATESINKREQUEST.fields_by_name['s3'].containing_oneof = _UPDATESINKREQUEST.oneofs_by_name['sink']
_LISTSINKOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetSinkRequest'] = _GETSINKREQUEST
DESCRIPTOR.message_types_by_name['ListSinksRequest'] = _LISTSINKSREQUEST
DESCRIPTOR.message_types_by_name['ListSinksResponse'] = _LISTSINKSRESPONSE
DESCRIPTOR.message_types_by_name['CreateSinkRequest'] = _CREATESINKREQUEST
DESCRIPTOR.message_types_by_name['CreateSinkMetadata'] = _CREATESINKMETADATA
DESCRIPTOR.message_types_by_name['UpdateSinkRequest'] = _UPDATESINKREQUEST
DESCRIPTOR.message_types_by_name['UpdateSinkMetadata'] = _UPDATESINKMETADATA
DESCRIPTOR.message_types_by_name['DeleteSinkRequest'] = _DELETESINKREQUEST
DESCRIPTOR.message_types_by_name['DeleteSinkMetadata'] = _DELETESINKMETADATA
DESCRIPTOR.message_types_by_name['ListSinkOperationsRequest'] = _LISTSINKOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListSinkOperationsResponse'] = _LISTSINKOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSinkRequest = _reflection.GeneratedProtocolMessageType('GetSinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSINKREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.GetSinkRequest)
  })
_sym_db.RegisterMessage(GetSinkRequest)

ListSinksRequest = _reflection.GeneratedProtocolMessageType('ListSinksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKSREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListSinksRequest)
  })
_sym_db.RegisterMessage(ListSinksRequest)

ListSinksResponse = _reflection.GeneratedProtocolMessageType('ListSinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKSRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListSinksResponse)
  })
_sym_db.RegisterMessage(ListSinksResponse)

CreateSinkRequest = _reflection.GeneratedProtocolMessageType('CreateSinkRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESINKREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESINKREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateSinkRequest)
  })
_sym_db.RegisterMessage(CreateSinkRequest)
_sym_db.RegisterMessage(CreateSinkRequest.LabelsEntry)

CreateSinkMetadata = _reflection.GeneratedProtocolMessageType('CreateSinkMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATESINKMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateSinkMetadata)
  })
_sym_db.RegisterMessage(CreateSinkMetadata)

UpdateSinkRequest = _reflection.GeneratedProtocolMessageType('UpdateSinkRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATESINKREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATESINKREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateSinkRequest)
  })
_sym_db.RegisterMessage(UpdateSinkRequest)
_sym_db.RegisterMessage(UpdateSinkRequest.LabelsEntry)

UpdateSinkMetadata = _reflection.GeneratedProtocolMessageType('UpdateSinkMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESINKMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateSinkMetadata)
  })
_sym_db.RegisterMessage(UpdateSinkMetadata)

DeleteSinkRequest = _reflection.GeneratedProtocolMessageType('DeleteSinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESINKREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.DeleteSinkRequest)
  })
_sym_db.RegisterMessage(DeleteSinkRequest)

DeleteSinkMetadata = _reflection.GeneratedProtocolMessageType('DeleteSinkMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETESINKMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.DeleteSinkMetadata)
  })
_sym_db.RegisterMessage(DeleteSinkMetadata)

ListSinkOperationsRequest = _reflection.GeneratedProtocolMessageType('ListSinkOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListSinkOperationsRequest)
  })
_sym_db.RegisterMessage(ListSinkOperationsRequest)

ListSinkOperationsResponse = _reflection.GeneratedProtocolMessageType('ListSinkOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListSinkOperationsResponse)
  })
_sym_db.RegisterMessage(ListSinkOperationsResponse)


DESCRIPTOR._options = None
_GETSINKREQUEST.fields_by_name['sink_id']._options = None
_LISTSINKSREQUEST.fields_by_name['folder_id']._options = None
_LISTSINKSREQUEST.fields_by_name['page_token']._options = None
_LISTSINKSREQUEST.fields_by_name['filter']._options = None
_CREATESINKREQUEST_LABELSENTRY._options = None
_CREATESINKREQUEST.oneofs_by_name['sink']._options = None
_CREATESINKREQUEST.fields_by_name['folder_id']._options = None
_CREATESINKREQUEST.fields_by_name['name']._options = None
_CREATESINKREQUEST.fields_by_name['description']._options = None
_CREATESINKREQUEST.fields_by_name['labels']._options = None
_CREATESINKREQUEST.fields_by_name['service_account_id']._options = None
_UPDATESINKREQUEST_LABELSENTRY._options = None
_UPDATESINKREQUEST.oneofs_by_name['sink']._options = None
_UPDATESINKREQUEST.fields_by_name['sink_id']._options = None
_UPDATESINKREQUEST.fields_by_name['name']._options = None
_UPDATESINKREQUEST.fields_by_name['description']._options = None
_UPDATESINKREQUEST.fields_by_name['labels']._options = None
_UPDATESINKREQUEST.fields_by_name['service_account_id']._options = None
_DELETESINKREQUEST.fields_by_name['sink_id']._options = None
_LISTSINKOPERATIONSREQUEST.fields_by_name['sink_id']._options = None
_LISTSINKOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTSINKOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTSINKOPERATIONSREQUEST.fields_by_name['filter']._options = None

_SINKSERVICE = _descriptor.ServiceDescriptor(
  name='SinkService',
  full_name='yandex.cloud.logging.v1.SinkService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2051,
  serialized_end=3604,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.logging.v1.SinkService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSINKREQUEST,
    output_type=yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK,
    serialized_options=b'\202\323\344\223\002\035\022\033/logging/v1/sinks/{sink_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.logging.v1.SinkService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSINKSREQUEST,
    output_type=_LISTSINKSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/logging/v1/sinks',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.logging.v1.SinkService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATESINKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\026\"\021/logging/v1/sinks:\001*\262\322*\032\n\022CreateSinkMetadata\022\004Sink',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.logging.v1.SinkService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATESINKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 2\033/logging/v1/sinks/{sink_id}:\001*\262\322*\032\n\022UpdateSinkMetadata\022\004Sink',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.logging.v1.SinkService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETESINKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\035*\033/logging/v1/sinks/{sink_id}\262\322*+\n\022DeleteSinkMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.logging.v1.SinkService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTSINKOPERATIONSREQUEST,
    output_type=_LISTSINKOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/logging/v1/sinks/{sink_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.logging.v1.SinkService.ListAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/logging/v1/sinks/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.logging.v1.SinkService.SetAccessBindings',
    index=7,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026\"1/logging/v1/sinks/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.logging.v1.SinkService.UpdateAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002924/logging/v1/sinks/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SINKSERVICE)

DESCRIPTOR.services_by_name['SinkService'] = _SINKSERVICE

# @@protoc_insertion_point(module_scope)
